==> talermerchantdemos-0.8.1.tar.gz: talermerchantdemos-0.8.1/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['talermerchantdemos',
 'talermerchantdemos.blog',
 'talermerchantdemos.donations',
 'talermerchantdemos.httpcommon',
 'talermerchantdemos.landing',
 'talermerchantdemos.survey']

package_data = \
{'': ['*'],
 'talermerchantdemos': ['.vscode/*',
                        'static/*',
                        'templates/*',
                        'translations/*',
                        'translations/ar/LC_MESSAGES/*',
                        'translations/de/LC_MESSAGES/*',
                        'translations/en/LC_MESSAGES/*',
                        'translations/es/LC_MESSAGES/*',
                        'translations/fr/LC_MESSAGES/*',
                        'translations/hi/LC_MESSAGES/*',
                        'translations/it/LC_MESSAGES/*',
                        'translations/ja/LC_MESSAGES/*',
                        'translations/ko/LC_MESSAGES/*',
                        'translations/pt/LC_MESSAGES/*',
                        'translations/ru/LC_MESSAGES/*',
                        'translations/sv/LC_MESSAGES/*',
                        'translations/tr/LC_MESSAGES/*',
                        'translations/zh_Hant/LC_MESSAGES/*'],
 'talermerchantdemos.blog': ['articles/*',
                             'articles/af/*',
                             'articles/ar/*',
                             'articles/az/*',
                             'articles/bg/*',
                             'articles/bn/*',
                             'articles/br/*',
                             'articles/bs/*',
                             'articles/ca/*',
                             'articles/cs/*',
                             'articles/da/*',
                             'articles/de/*',
                             'articles/el/*',
                             'articles/en/*',
                             'articles/eo/*',
                             'articles/es/*',
                             'articles/fa/*',
                             'articles/fi/*',
                             'articles/fr/*',
                             'articles/gl/*',
                             'articles/he/*',
                             'articles/hr/*',
                             'articles/hu/*',
                             'articles/id/*',
                             'articles/it/*',
                             'articles/ja/*',
                             'articles/kn/*',
                             'articles/ko/*',
                             'articles/lt/*',
                             'articles/mk/*',
                             'articles/ml/*',
                             'articles/ms/*',
                             'articles/nb/*',
                             'articles/nl/*',
                             'articles/pl/*',
                             'articles/ro/*',
                             'articles/ru/*',
                             'articles/sk/*',
                             'articles/sl/*',
                             'articles/sq/*',
                             'articles/sr/*',
                             'articles/sv/*',
                             'articles/ta/*',
                             'articles/tl/*',
                             'articles/tr/*',
                             'articles/uk/*',
                             'articles/zh/*',
                             'data/*']}

install_requires = \
['Flask>=2.0.2,<3.0.0',
 'beautifulsoup4>=4.10.0,<5.0.0',
 'requests>=2.26.0,<3.0.0',
 'taler-util>=0.8.3,<0.9.0']

entry_points = \
{'console_scripts': ['taler-merchant-demos = talermerchantdemos.cli:run']}

setup_kwargs = {
    'name': 'talermerchantdemos',
    'version': '0.8.1',
    'description': 'Taler merchant demos',
    'long_description': None,
    'author': 'Florian Dold',
    'author_email': 'dold@taler.net',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)

==> talermerchantdemos-0.8.2.tar.gz: talermerchantdemos-0.8.2/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['talermerchantdemos',
 'talermerchantdemos.blog',
 'talermerchantdemos.donations',
 'talermerchantdemos.httpcommon',
 'talermerchantdemos.landing',
 'talermerchantdemos.survey']

package_data = \
{'': ['*'],
 'talermerchantdemos': ['.vscode/*',
                        'static/*',
                        'templates/*',
                        'translations/*',
                        'translations/ar/LC_MESSAGES/*',
                        'translations/de/LC_MESSAGES/*',
                        'translations/en/LC_MESSAGES/*',
                        'translations/es/LC_MESSAGES/*',
                        'translations/fr/LC_MESSAGES/*',
                        'translations/hi/LC_MESSAGES/*',
                        'translations/it/LC_MESSAGES/*',
                        'translations/ja/LC_MESSAGES/*',
                        'translations/ko/LC_MESSAGES/*',
                        'translations/pt/LC_MESSAGES/*',
                        'translations/ru/LC_MESSAGES/*',
                        'translations/sv/LC_MESSAGES/*',
                        'translations/tr/LC_MESSAGES/*',
                        'translations/zh_Hant/LC_MESSAGES/*'],
 'talermerchantdemos.blog': ['articles/*',
                             'articles/af/*',
                             'articles/ar/*',
                             'articles/az/*',
                             'articles/bg/*',
                             'articles/bn/*',
                             'articles/br/*',
                             'articles/bs/*',
                             'articles/ca/*',
                             'articles/cs/*',
                             'articles/da/*',
                             'articles/de/*',
                             'articles/el/*',
                             'articles/en/*',
                             'articles/eo/*',
                             'articles/es/*',
                             'articles/fa/*',
                             'articles/fi/*',
                             'articles/fr/*',
                             'articles/gl/*',
                             'articles/he/*',
                             'articles/hr/*',
                             'articles/hu/*',
                             'articles/id/*',
                             'articles/it/*',
                             'articles/ja/*',
                             'articles/kn/*',
                             'articles/ko/*',
                             'articles/lt/*',
                             'articles/mk/*',
                             'articles/ml/*',
                             'articles/ms/*',
                             'articles/nb/*',
                             'articles/nl/*',
                             'articles/pl/*',
                             'articles/ro/*',
                             'articles/ru/*',
                             'articles/sk/*',
                             'articles/sl/*',
                             'articles/sq/*',
                             'articles/sr/*',
                             'articles/sv/*',
                             'articles/ta/*',
                             'articles/tl/*',
                             'articles/tr/*',
                             'articles/uk/*',
                             'articles/zh/*',
                             'data/*']}

install_requires = \
['Flask-Babel>=2.0.0,<3.0.0',
 'Flask>=2.0.2,<3.0.0',
 'beautifulsoup4>=4.10.0,<5.0.0',
 'requests>=2.26.0,<3.0.0',
 'taler-util>=0.8.3,<0.9.0']

entry_points = \
{'console_scripts': ['taler-merchant-demos = talermerchantdemos.cli:run']}

setup_kwargs = {
    'name': 'talermerchantdemos',
    'version': '0.8.2',
    'description': 'Taler merchant demos',
    'long_description': None,
    'author': 'Florian Dold',
    'author_email': 'dold@taler.net',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
